<%--
 * Component: archive
 *
 * Description:
 *   WEB interface to get a study from the archive.
 *
 * Parameters:
 *
 *  @param cDevStudy   Device Id + ' ' + Study (multivalue, Device Id and Study Instance UID are concatenated by space)
 *                     Device Id is the Id of the archive device where the study is archived
 *                     Study is the Study Instance UID of the study to be retrieved from the Archive
 *  @param cUser       User ID of the user initiated the retrieve (when request received from child server)
 *  @param cForced     Force retrieving the study (if it's in Staged state)  
 *
 * Last Updated     : $Author$
 * Update Date Time : $Date$
 * RCS File Name    : $RCSfile$
 * RCS Revision     : $Revision$
 * Locked by        : $Locker$
 * Symbolic name    : $Name$
 * State            : $State$
--%><%@
	page import="imagemed.util.*,imagemed.jsputil.*,java.util.*, imagemed.imsession.*,java.sql.*, imagemed.archive.ArchiveRetrieve, java.text.Format"

%><%@
	page errorPage ="../main/exceptionHandler.jsp"

%><%
	IMSession is = new IMSession(request, response, out);
	Syslog slog = new Syslog("archive_get",0,IMEnvBase.getEnv("LOG_FACILITY"));

	String[] parDevStudy = request.getParameterValues("cDevStudy");
	Properties studies = new Properties(); // Study/device pairs of studies to be retrieved
	if (parDevStudy != null) {
		for (int i = 0; i < parDevStudy.length; i++) {
			int pos = parDevStudy[i].indexOf(' ');
			if (pos == -1)
				continue;

			studies.setProperty(parDevStudy[i].substring(pos + 1), parDevStudy[i].substring(0, pos));
		}
	}

	boolean isForced = "true".equals(request.getParameter("cForced"));
	String target = request.getParameter("cTarget");

	String remoteAddress = request.getRemoteAddr();

	Properties peerPrp = null; // get request cen be received from either child or parent dotcom devices

	String errMsgID = null;

	String referrer = request.getHeader("REFERER");
	is.regDest = referrer == null ? "/archive/index.jsp" :  referrer;

	String tab = "archive/index.jsp";
	if (is.regDest.indexOf("/qr/index.jsp") != -1 || is.regDest.indexOf("/qr/retrieve.jsp") != -1) {
		tab = "qr/index.jsp";
	}
	else if (is.regDest.indexOf("/prior/index.jsp") != -1 || is.regDest.indexOf("/cases/index.jsp") != -1) {
		tab = "cases/index.jsp";
	}

	if (studies.isEmpty()) {
		slog.syslog(Syslog.LOG_DEBUG, "Missing parameter");
		errMsgID = "ARCHIVE_INDEX_NO_STUDY";
	}
	else {
		if (remoteAddress == null) {
			errMsgID = "ARCHIVE_GET_STUDY_NOT_PERMITTED";
			slog.syslog(Syslog.LOG_DEBUG, "Getting study from the archive not permitted [1]");
		}
		else {
			try {
				peerPrp = DotcomToolbox.checkClient(is, null, false);
				is.bRegNotNeeded = true;
				is.bCheckHttpsAndRedirect = false;
				is.regRights = "S";
				is.setRegID( request.getParameter("cUser") );

				if (peerPrp != null)
					peerPrp.setProperty("IP",remoteAddress);
			}
			catch (Throwable th) {
				slog.syslog(Syslog.LOG_DEBUG, "checkClient Failed [" + Helper.throwable2String(th) + "]" );
			}
		}
	}
	if (!is.regOK()) {
		slog.syslog(Syslog.LOG_DEBUG, "is.regOK() returned false" );
		return;
	}

	imagemed.taskd.IMScriptContext context = imagemed.taskd.IMScriptContext.readJobContextFrom( request );	

	boolean isAjax = "true".equals(request.getParameter("cAjax"));
	
	// If the page is called from a WEB browser, collect 
	// local studies and do not start retrieve for these studies
	List<String> localStudies = new ArrayList<String>();
	if (!is.bRegNotNeeded) {
		for (Enumeration<?> e = studies.propertyNames(); e.hasMoreElements() && target == null; ) {
			String study = (String) e.nextElement();
			
			try {
				// Check if the study is here by a select from the worklist
				String query = "select STYIUID from " + IMEnvBase.getEnv("STUDYTBL") +
						" where STYIUID='" + study + "' and Dcstudy_D='no' and FOLDER=''";
				ResultSet rs = IMEnv.getDB().prepareStatement(query).executeQuery();
				if (rs.first()) {
					localStudies.add(study);
					studies.remove(study);
				}
				else {
					StoreState storestate = new StoreState(study);
					storestate.load();
					if ("Staged".equals(storestate.getAttribute("StageState", "None")) && !isForced) {
						localStudies.add(study);
						studies.remove(study);
					}
				}
			}
			catch (Throwable th) {
				Helper.DEBUG("archive/get.jsp", "Error: "+Helper.throwable2String(th));
			}
		}
		
		String backURL = request.getParameter("cBack");
		if(null == backURL) {
			backURL = request.getHeader("Referer");
		}
		if (null == backURL)
			backURL = "/archive/index.jsp";
		boolean isIntegrated = "true".equals(is.imRequest.getVal("cIntegrated"));
		if (!isAjax) {
%><HTML><HEAD><TITLE>Get study from archive</TITLE>
  <META http-equiv="Refresh" content="3; URL=<%=backURL%>">
<%	
			imagemed.http.tabs.TabBean.writeStyleOnly(is);
			JSHelper.printJsInclude( out, JSHelper.TABLESCRIPTS_JS );
			TabToolbox.writeIMpopup(out);
%>
    </HEAD>
    <BODY<%=isIntegrated?" class='dark'":"" %>>
<%
			if (!isIntegrated) {
				TabToolbox.makeTabs( is, is.tabbean, tab, "White");
			}
		}
	}


	if (-1 == is.regRights.indexOf('S')) {
		errMsgID = "ARCHIVE_GET_NO_ACCESS_RIGHTS";
	}

	if (errMsgID != null) {
		if (isAjax) {
			out.print( LocalizedMessage.getSimpleMessage( errMsgID ) );
		}
		else if (!is.bRegNotNeeded) {
%><center><font color=red><h3><%= LocalizedMessage.getSimpleMessage( errMsgID ) %></h3></font></center></body></html><%		
		}
		else {
			response.setStatus(601);
		}
		return;
	}

	slog.syslog(Syslog.LOG_DEBUG, "Studies to be retrieved" );
	for (Enumeration<?> e = studies.propertyNames(); e.hasMoreElements(); ) {
		String study = (String) e.nextElement();
		String device = studies.getProperty(study);

		slog.syslog(Syslog.LOG_DEBUG, "Study: " + study + " Device: " + device);
	}

	slog.syslog(Syslog.LOG_DEBUG, "Start retrieving studies" );
	ArchiveRetrieve archiveRetrieve = new ArchiveRetrieve(is, context, peerPrp, isForced, target);
	String errMsg = archiveRetrieve.getStudies(studies);

	if (errMsg != null) {
		if (isAjax) {
			out.print( errMsg );
		}
		else if (!is.bRegNotNeeded) {
%><center><font color=red><h3><%= errMsg %></h3></font></center></body></html><%
		}
		else {
			response.setStatus(601);
		}
		return;
	}

	if (isAjax) {
		StringBuilder sb = new StringBuilder();
		if( target == null ) {
			for (Enumeration<?> e = studies.propertyNames(); e.hasMoreElements(); ) {
				String study = (String) e.nextElement();
				sb.append( LocalizedMessage.getCompoundMessage( "ARCHIVE_GET_GETTING_STUDY", new Format[] { null }, new Object[] { is.imRequest.getVal( "cDesc_" + study, study ) }, false ) );
			}
			for (int i=0; i<localStudies.size(); i++) {
				String study = localStudies.get(i);
				sb.append( LocalizedMessage.getCompoundMessage( "ARCHIVE_GET_SKIPPING_STUDY", new Format[] { null }, new Object[] { is.imRequest.getVal( "cDesc_" + study, study )  }, false ) );
			}
		} 
		else {
			for (Enumeration<?> e = studies.propertyNames(); e.hasMoreElements(); ) {
				String study = (String) e.nextElement();
				sb.append( LocalizedMessage.getCompoundMessage( "ARCHIVE_GET_MOVING_STUDY", new Format[] { null, null }, new Object[] { is.imRequest.getVal( "cDesc_" + study, study ), target  }, false ) );
			}
		}
		out.print( "OK: "+sb.toString() );
	}
	else if (!is.bRegNotNeeded) {
		%><center><h3><%
		if( target == null ) {
			for (Enumeration<?> e = studies.propertyNames(); e.hasMoreElements(); ) {
				String study = (String) e.nextElement();
				%><%= LocalizedMessage.getCompoundMessage( "ARCHIVE_GET_GETTING_STUDY", new Format[] { null }, new Object[] { is.imRequest.getVal( "cDesc_" + study, study ) }, false )%><%
			}
			for (int i=0; i<localStudies.size(); i++) {
				String study = localStudies.get(i);
				%><%= LocalizedMessage.getCompoundMessage( "ARCHIVE_GET_SKIPPING_STUDY", new Format[] { null }, new Object[] { is.imRequest.getVal( "cDesc_" + study, study )  }, false )%><%
			}
		} else {
			for (Enumeration<?> e = studies.propertyNames(); e.hasMoreElements(); ) {
				String study = (String) e.nextElement();
				%><%= LocalizedMessage.getCompoundMessage( "ARCHIVE_GET_MOVING_STUDY", new Format[] { null, null }, new Object[] { is.imRequest.getVal( "cDesc_" + study, study ), target  }, false )%><%
			}
		}
		%></h3></center></body></html><%
	}

	if (true) {
		// For avoiding extra newline(s)
		return;
	}
%>
